@@ -1,4 +1,4 @@
-/* Copyright 2012 Naikel Aparicio. All rights reserved.
+/* Copyright 2013 Naikel Aparicio. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -22,8 +22,8 @@
  * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * The views and conclusions contained in the software and documentation
- * are those of the authors and should not be interpreted as representing
- * official policies, either expressed or implied, of Eeli Reilin.
+ * are those of the author and should not be interpreted as representing
+ * official policies, either expressed or implied, of the copyright holder.
  */
 
 #ifndef CHATIMAGEITEM_H
@@ -48,6 +48,7 @@ public:
 
 signals:
     void mediaDownload(FMessage message);
+    void voiceNotePlayed(FMessage message);
 
 public slots:
     void downloadOrViewImage();
@@ -57,6 +58,8 @@ public slots:
     void setButton();
     void updateTimestamp();
     void updateProgress(float p);
+    void updateTime(int current);
+    void finishedAudioPlay();
     void updateUri(QString uri);
     void updateImage(FMessage message);
     void resetButton();
